/*
 * Copyright (c) 2019-2023 VMware Carbon Black, all rights reserved
 */

// Package logger -- implements logging wrappers around kinesis and elasticsearch streams as well as providing
// better test identification logging.
//
//	Version: 1.0
//	Contact: team-enki@vmware.com
package logger

import (
	"log"
)

// HeaderFunc -- Visually obvious test breakup
func HeaderFunc(tag string) func() {
	Header(tag)

	return func() {
		Tailer(tag)
	}
}

// Header -- Create a test header banner that makes it easier to pick out tests in the log.
func Header(tag string) {
	p := padding(tag)
	log.Printf("===== %s %s\n", tag, p)
}

// Tailer -- Create a test trailing banner that makes it easier to pick out tests in the log.
func Tailer(tag string) {
	p := padding(tag)
	log.Printf("%s %s =====\n\n", p, tag)
}

// padding -- Generate header/trailer banner fill
func padding(tag string) string {
	useLen := 80 - (len(tag) + 7)
	if useLen < 5 {
		useLen = 5
	}
	b := make([]byte, useLen)
	for i := range b {
		b[i] = '='
	}
	return string(b)
}
