/*
 * Copyright (c) 2019-2023 VMware Carbon Black, all rights reserved
 */

// Package logger implements logging wrappers around kinesis and elasticsearch streams.
package logger

import (
	"strings"

	"github.com/rs/zerolog"
)

// EsLogger is a wrapper over zero log logger to adhere to es client logger interface
type EsLogger struct {
	logger *zerolog.Logger
	level  zerolog.Level
}

const deprecationWarningPrefix = "Deprecation warning:"

// Printf prints the log
func (l *EsLogger) Printf(format string, args ...interface{}) {
	// check for the deprecation warning prefix added by elastic client to supress deprecation warning logspam
	if strings.HasPrefix(format, deprecationWarningPrefix) {
		return
	}

	switch l.level {
	case zerolog.InfoLevel:
		l.logger.Info().Msgf(format, args...)
	case zerolog.ErrorLevel:
		l.logger.Error().Msgf(format, args...)
	case zerolog.WarnLevel:
		l.logger.Warn().Msgf(format, args...)
	case zerolog.DebugLevel:
		l.logger.Debug().Msgf(format, args...)
	}
}

// NewEsLogger creates a new wrapper around zero logger
func NewEsLogger(lLogger *zerolog.Logger, level zerolog.Level) *EsLogger {
	return &EsLogger{
		logger: lLogger,
		level:  level,
	}
}
