/*
 * Copyright (c) 2019-2023 VMware Carbon Black, all rights reserved
 */

package logger

import (
	"github.com/rs/zerolog"
	"github.com/vmware/vmware-go-kcl/logger"
)

// KclLogger is a wrapper over zero log logger to adhere to logrus interface to be used in kcl library.
type KclLogger struct {
	logger *zerolog.Logger
}

// Debugf logs in debug level.
func (l *KclLogger) Debugf(format string, args ...interface{}) {
	l.logger.Debug().Msgf(format, args...)
}

// Infof logs in info level.
func (l *KclLogger) Infof(format string, args ...interface{}) {
	l.logger.Info().Msgf(format, args...)
}

// Warnf logs in warn level
func (l *KclLogger) Warnf(format string, args ...interface{}) {
	l.logger.Warn().Msgf(format, args...)
}

// Errorf logs error
func (l *KclLogger) Errorf(format string, args ...interface{}) {
	l.logger.Error().Msgf(format, args...)
}

// Fatalf logs fatal
func (l *KclLogger) Fatalf(format string, args ...interface{}) {
	l.logger.Fatal().Msgf(format, args...)
}

// Panicf logs panic msg
func (l *KclLogger) Panicf(format string, args ...interface{}) {
	l.logger.Fatal().Msgf(format, args...)
}

// WithFields is not supported. This is added to adhere to logrus interface.
func (l *KclLogger) WithFields(_ logger.Fields) logger.Logger {
	return l
}

// NewKclLogger creates a new wrapper around zero logger
func NewKclLogger(lLogger *zerolog.Logger) *KclLogger {
	return &KclLogger{
		logger: lLogger,
	}
}
