// Package publisher handles publishing of LCT data to other receivers
//
//nolint:dupl // This needs more significant refactoring to eliminate the duplicate code
package publisher

import (
	"context"

	"github.com/rs/zerolog"
	elasticV5 "gopkg.in/olivere/elastic.v5"

	"gitlab.bit9.local/psc/platform/ems/hello/last-contact-updater/internal/config"
)

// ElasticSearchBulkProcessorsV5 creates a map of elastic search bulk processors for different clusters.
type ElasticSearchBulkProcessorsV5 struct {
	ClientsMap     *ElasticSearchClientsMap
	Log            *zerolog.Logger
	bulkProcessors map[string]*elasticV5.BulkProcessor
	Conf           *config.Configurations
}

func (e *ElasticSearchBulkProcessorsV5) getOrCreateProcessor(env string, afterFn elasticV5.BulkAfterFunc) *elasticV5.BulkProcessor {
	if e.bulkProcessors == nil {
		e.bulkProcessors = make(map[string]*elasticV5.BulkProcessor)
	}
	if e.bulkProcessors[env] == nil {
		e.Log.Warn().Msgf("Creating ES 5.6 bulk processor for env %v", env)
		proc, err := elasticV5.NewBulkProcessorService(e.ClientsMap.GetEsClientV5(env)).
			Workers(e.Conf.BulkProcessorWorkerThreads).
			BulkActions(e.Conf.EsBatchSizeEnvMap[env]).
			Stats(true).
			After(afterFn).
			Do(context.Background())
		if err != nil {
			e.Log.Fatal().Msgf("Failed to create bulk processor for env %v", env)
		} else {
			e.bulkProcessors[env] = proc
			err = proc.Start(context.Background())
			if err != nil {
				e.Log.Fatal().Msgf("Failed to start bulk processor for es env %v", env)
			}
		}
	}
	return e.bulkProcessors[env]
}

// Flush is exposed for testing purposes only.
func (e *ElasticSearchBulkProcessorsV5) Flush(cluster string) error {
	return e.bulkProcessors[cluster].Flush()
}
